Sign Up | Capital Bikeshare
Author: Alta Bicycle Share
Description: Your bike sharing system in Washington, D.C.
Keywords: Bicycle Sharing Systems

# Join

By mail: For Annual, Annual Installment, 30-Day, Daily Key and corporate memberships, please complete this form to open an account and have your fob (and helmet, if purchased) mailed to you.

In person: To open an account and pick up your fob in person for Annual, Annual Installment, 30-Day, Daily Key and corporate memberships, visit any Arlington County Commuter Store. Your fob will be activated on the spot and ready for use. Hours for pick-up are Monday - Friday between 9:30am - 5pm and Saturday at the Ballston and Rosslyn locations between 8am - 2pm. If you purchase a helmet, it will be mailed separately.

24-hour and 3-day memberships can be purchased at any station kiosk.

Note: You must be at least 16 years of age to become a Member of Capital Bikeshare.
Personal Information

NOTE: Please provide the address where you wish to receive your Capital Bikeshare key. Please allow up to 7 business days to receive your key.

*Gender Male Female
*First Name
*Last Name
*Date of Birth
/
/
*Phone - -
Alternate Phone - -
*Email
*Street Number (or PO Box Number)
*Street Name (enter "PO Box" if it is a PO Box)
Apartment
*City
*State
*Country
*Postal Code
Account Information
*User Name (no spaces)
*Password (no spaces)
*Confirm password (no spaces)

*Membership Type (select one) Help me choose my perfect membership type!
Standard | Enable Auto-Renew What's This?
Corporate | Company Password Check

Helmet Option
Check this box if you would like to purchase a Helmet for an additional cost of $16.00.

Model | Top Gear Model 9
Sizing | Helmet fits 22.83 to 24.4 inches through instant fitting dial turn retention system, includes snap-on visor, a quick release Nexus buckle, and meets the CPSC standards.
Total Price | $16.00

NOTE: Helmets will be shipped separately from your member key within 5 business days. All helmet sales are final. Inquiries regarding helmet shipments may be made to helmets@capitalbikeshare.com.

Redeem a Gift Certificate

To redeem your gift certificate, enter the certificate number in the space below. After entering your certificate number, you must provide your credit card information to establish your account. You will be responsible for any trip usage fees incurred during your membership. Trip fees are charged for trips lasting more than 30 minutes.

Gift certificate number
Credit/Debit Card Information don't have one?
*Card Number
*Validation Code (3 numbers on back of card)
*Expiration
/
*Cardholder Name

*Address associated with card

Same address as above
*Street Number (or PO Box number)
*Street Name (enter "PO Box" if it is a PO Box)
Apartment
*City
*State
*Postal Code
Rental Agreement

# Capital Bikeshare Member Agreement, Liability Waiver, and Release

Capital Bikeshare is a self-serve bicycle rental system ("Service"), made available by Arlington County, Virginia, the District of Columbia, Montgomery County, Maryland, and the City of Alexandria (“Clients”) and managed by Alta Bicycle Share, Inc. ("Alta," "Our," or "We"). In consideration of your use of any Service, Alta requires that you ("Member", "You", or "Your") agree to all terms and conditions in this User Agreement, Liability Waiver, and Release ("Agreement"), which are intended to promote the safe use of Capital Bikeshare bicycles, and which apply to all Registered Members and to all Casual Members, as defined below. In this Agreement, "Member" means and includes both Registered Members and Casual Members.

Section 1 Modifications to Agreement. Alta, in consultation with our Clients, reserves the right to unilaterally amend, modify, or change this Agreement, at any time and from time to time in its sole discretion, without notice and without Member's consent. By continuing to use any Service after any amendment, modification, or change, Member has agreed to be bound by all such amendments, modifications, and changes. Member must carefully review this Agreement on a regular basis to maintain awareness of all amendments, modifications, and changes. Whenever a change is made to this Agreement, Alta will post a notification on www.capitalbikeshare.com ("Website").

Section 2 Term of Agreement. The term of this Agreement begins when You first use any Service, and the term ends 10 years after Your last use of any Service; provided, however, that Your personal financial responsibility under Section 15 of this Agreement, titled Credit Card Matters, expires one year after the later of (i) Your last use of any Service, or (ii) the expiration of Your Membership. At any time and from time to time, and without Member's consent, Alta may unilaterally terminate Your right to use any Service, in Alta's sole discretion and without any notice or cause. This Agreement remains in full force and effect after any termination of Your right to use any Service.

Section 3 Service System. The Service is comprised of Capital Bikeshare bicycle stations ("Stations"), which include an automated pay station ("Pay Station"), and separate stands that allow the docking of Capital Bikeshare bicycles ("Bike Docks"). The Stations are for the purposes of the renting, docking, and locking of Capital Bikeshare bicycles, as well as the identification of the Member. Under the Service, Capital Bikeshare bicycles can be rented and returned to any Station.

Section 4 Membership to Service. Member may purchase a long-term membership for the Service ("Membership"), which can be for a period of either one year, 30 days, or a Daily Key membership ("Membership"). Daily Key members will be issued a key which will activate one day memberships when used. To purchase a Membership, Member must complete a registration form and create an account ("Account") at www.capitalbikeshare.com ("Website"), to become a Registered member ("Registered Member"). When a Member subscribes to the Service, Alta will charge the Registered Member's credit card the amount for the Membership, as described in Section 5. Once Registered Member's credit card payment clears, Alta will mail a system key to the mailing address listed by Registered Member. Member must activate the system key on the Website, under the "Member Login" heading, before using the Service for the first time. A Membership becomes valid and active once the system key is activated on the Website. The one year and 30 days memberships allows Registered Member to use the Service without having to pay the $7 charge applicable to Casual 24-Hour Members or the $15 charge applicable to Casual 3-Day Members (definitions below), and Daily Key members will be charged the one day $7 charge for each day they activate their key; provided; however, that Registered Member must still pay the hourly rates as set forth in Section 7 for all trips in excess of 30 minutes. Within one year after a prior Membership expires, Registered Member may renew the Membership on the Website, under the "Member Login" heading. If the Membership is not renewed within this period of time, then Registered Member might need to (i) take certain actions to reactivate Registered Member's old Account, or (ii) create an entirely new Account for a new Membership. The Membership, and the personal identification number and system key related thereto, are non-transferable and may be terminated if Member breaches this Agreement, as decided by Alta in its sole discretion. If a Membership is terminated for any reason, then no refund is provided.

Section 5 Registered Member Rates and Benefits. Member may purchase a Membership only by using a Visa or MasterCard credit card. A one-year "Annual" Membership may be purchased for $75, and a 30-day "Monthly" Membership may be purchased for $25 (taxes are included), a one-year "Annual Installment" Membership payable in monthly installments may be purchased for $84, a Daily Key Membership may be purchased for $10. For Annual, Monthly and Installment memberships, on the 10th day of each month, the total amount of chargeable trips (i.e., those trips in excess of 30 minutes) and/or monthly installment payments will be charged to Registered Member's credit card. Daily Key members will be charged for usage fees at the end of each one day membership activated. At any time a registered member can access their trip history and associated charges by logging into their member profile on the website. If Registered Member has any claim or dispute regarding a chargeable trip, then Registered Member must, within 10 business days from the end of the prior month with the disputed claim, provide to Alta the corresponding trip number to identify the place and time the Capital Bikeshare bicycle was rented and returned. The receipt, if any, indicating the date and time the Capital Bikeshare bicycle was returned would be additional proof that the Capital Bikeshare bicycle had been properly returned. Registered Member is encouraged to maintain all trip receipts. All annual memberships created on or after March 13, 2012 will be enrolled in the Auto-Renew feature by default unless the Auto-Renew Membership box is deselected on the Join form during membership purchase. Registered Members whom have been enrolled into auto-renew may discontinue their membership from auto-renewing by deselecting the Auto-Renew Membership box found on the Profile page within the Member Area of the Website. Registered Members whom wish to be enrolled into auto-renew may do so by selecting the Auto-Renew Membership box found on the Profile page within the Member Area of the Website.

Section 6 Casual Membership Rates and Benefits. f Member does not elect to purchase an Annual, 30-Day Membership, or Daily Key membership and merely uses the Service for any time between 24-Hours and 3-Days, then Member is a Casual Member. A Casual Member must pay a $7 flat fee for a 24-Hour Membership or $15 flat fee for a 3-Day Membership, plus additional hourly charges pursuant to the rates set forth in Section 7. Casual Members have the option of renting a second bike using the same credit card. When a Casual Member signs up to the Service at the Station, Alta will charge $101 to ensure the credit card is valid and that amount could remain on the Casual Member's credit card for an amount of time to be determined by the Member's bank's policies regarding holds. This hold will be placed on Casual Member's credit card for each bike rented. In this Agreement, "Member" also includes anyone who is a Casual Member.

Section 7 Hourly Rates. In addition to the Registered and Casual Membership rates outlined in Sections 4 to 6, all Members are subject to hourly rates. The hourly rates are set forth in the chart below. So long as Member returns the Capital Bikeshare bicycle to a Bike Dock within 30 minutes, no hourly charge applies. Member may remove another Capital Bikeshare bicycle from a Bike Dock after returning the previous Capital Bikeshare bicycle after a 15 second wait.

Ride Time | 30-day, Annual, Annual Installment, Daily Key Members
0-29:59 min | FREE
30:00-59:59 min | $1.50
60:00-89:59 min | $4.50
90:00-119:59 min | $10.50
2:00:00 - 2:29:59 hours | $16.50
2:30:00 - 2:59:59 hours | $22.50
3:00:00 - 3:29:59 hours | $28.50
3:30:00 - 3:59:59 hours | $34.50
4:00:00 - 4:29:59 hours | $40.50
4:30:00 - 4:59:59 hours | $46.50
5:00:00 - 5:29:59 hours | $52.50
5:30:00 - 5:59:59 hours | $58.50
6:00:00 - 6:29:59 hours | $64.50
6:30:00 - 23:59:59 hours | $70.50
> 24:00:00 hours | $1,000.00

Ride Time | 24-hour and 3-day Members
0-29:59 min | FREE
30:00-59:59 min | $2.00
60:00-89:59 min | $6.00
90:00-119:59 min | $14.00
2:00:00 - 2:29:59 hours | $22.00
2:30:00 - 2:59:59 hours | $30.00
3:00:00 - 3:29:59 hours | $38.00
3:30:00 - 3:59:59 hours | $46.00
4:00:00 - 4:29:59 hours | $54.00
4:30:00 - 4:59:59 hours | $62.00
5:00:00 - 5:29:59 hours | $70.00
5:30:00 - 5:59:59 hours | $78.00
6:00:00 - 6:29:59 hours | $86.00
6:30:00 - 23:59:59 hours | $94.00
> 24:00:00 hours | $1,000.00

Section 8 Availability of Service. Alta makes every effort to provide the Service for 365 days per year, but does not guarantee that the Service will be available at all times, as force majeure events or other circumstances might prevent Alta from providing the Service. Access to the Service also is conditioned on the availability of Capital Bikeshare bicycles at each Station. Alta does not represent or warrant the availability of any Service or the availability of any Capital Bikeshare bicycle at any Station. Member may use the Website to consult the inventory of Capital Bikeshare bicycles available at a Station.

Section 9 Directions for Using Service.

Section 9.1 Removing Bicycle.

Section 9.1(a) Removing Bicycle by Registered Member. Registered Member must insert their system key into the reader slot on the Bike Dock keyboard, to remove the Capital Bikeshare bicycle from the Bike Dock. After the system key has been inserted into the reader slot, Registered Member has 15 seconds to remove the Capital Bikeshare bicycle from the Bike Dock. The signal light remains yellow during the validation of Registered Member's system key, and the signal light turns green when the Capital Bikeshare bicycle can be removed. Two sounds signals are also emitted. If the Capital Bikeshare bicycle is not removed within 15 seconds, the Bike Dock locks and Registered Member must repeat the process described above.

Section 9.1(b) Removing Bicycle by Casual Member. A Casual Member must insert a credit card into the Pay Station, agree to Alta’s Terms and Conditions, and obtain a 5-digit code after completing the payment process. The Casual Member must then type the 5-digit code into the Bike Dock keyboard, to remove the Capital Bikeshare bicycle from the Bike Dock. After the 5-digit code has been entered, the Casual Member has 15 seconds to remove the Capital Bikeshare bicycle from the Bike Dock. The signal light remains yellow during the validation of the Casual Member's 5-digit code, and the signal light turns green when the Capital Bikeshare bicycle can be removed. Two sounds signals are also emitted. If the Capital Bikeshare bicycle is not removed within 15 seconds, the Bike Dock locks and the Casual Member must repeat the process described above. Each time a Casual Member would like to remove a new Capital Bikeshare bicycle from a Bike Dock, Casual Member must insert a credit card into the Pay Station and obtain a new 5-digit code, to remove the next Capital Bikeshare bicycle. A Casual Member may remove up to two Capital Bikeshare bicycles on each credit card account, and Casual Member will be charged for the use of two Capital Bikeshare bicycles. The Casual Member using the second bicycle must agree to all Terms and Conditions before a code is issued.

Section 9.2 Returning Bicycle. To return the Capital Bikeshare bicycle, Member must secure it into an available Bike Dock. A sound signal is emitted, and the signal light turns yellow, then green, confirming that the Capital Bikeshare bicycle has been properly secured to the Bike Dock. If the Capital Bikeshare bicycle is not properly secured in the Bike Dock, then the signal light turns red, and a longer signal sound is emitted. If the signal light turns red, Member must repeat the operation until the signal light turns green, and the Capital Bikeshare bicycle is properly secured in the Bike Dock. If the signal light does not turn green, Member must return the Capital Bikeshare bicycle to another available Bike Dock. If there is no available Bike Dock at the Station, then Members must push the "Time Credit" icon on the Pay Station screen under the "More Options" menu. Registered Members must input the 7-digit code on the back of the system key or insert their key into the reader slot on the Pay Station and Casual Members must swipe their credit card at the Pay Station, to obtain an additional 15-minute credit in which to return the Capital Bikeshare bicycle to another Station. No fee is charged to Member for the additional 15-minute credit. Member may immediately remove another Capital Bikeshare bicycle from a Bike Dock. Any Capital Bikeshare bicycle that is not properly secured remains the sole responsibility of Member, and the hourly rates set forth in Section 7 will be charged until the Capital Bikeshare bicycle is properly secured.

Section 9.3 Obtaining Receipt. Member may print a receipt to confirm that the Capital Bikeshare bicycle has been properly returned to the Bike Dock. The date and time of return are indicated on the receipt, and the receipt may be used to dispute a chargeable trip. To obtain a receipt, Member must push the "Rental Receipt" icon on the Pay Station screen under the "More Options" menu. Registered Members must input the 7-digit code on the back of the system key or insert their system key into the reader slot on the Pay Station and Casual Members must swipe their credit card at the Pay Station.

Section 9.4 Permitted Period of Continuous Use; Lost or Stolen Bicycle. Use of the Service is limited to a period of 24 consecutive hours ("Permitted Period of Continuous Use"). If Member maintains possession of the Capital Bikeshare bicycle beyond the Permitted Period of Continuous Use, then the Capital Bikeshare bicycle is deemed lost or stolen, Member's credit card will be charged a fee of $1,000, and a police report may be filed with local authorities. Alta will attempt to contact the Member via telephone and/or email prior to charging the credit card, using the contact information provided by the Member upon subscribing, in an attempt to locate the Capital Bikeshare bicycle. The data generated by the Service's computer is conclusive evidence of the period of use of a Capital Bikeshare bicycle by Member. For any disappearance of a Capital Bikeshare bicycle where Member will be held responsible, Member must report the disappearance to Alta within 24 hours following the disappearance and must report the disappearance to the local police department within 48 hours. Any use that exceeds the Permitted Period of Continuous Use is deemed a disappearance of the Capital Bikeshare bicycle, until the Capital Bikeshare bicycle is found or returned to a Bike Dock.

Section 9.5 Lost or Damaged System Key. If Member's system key has been lost or damaged, a replacement may be purchased by calling 877-430-BIKE (2453) or by emailingcustomerservice@capitalbikeshare.com and reporting that the system key has been lost or damaged. Members are required to report stolen or lost keys immediately so the key may be deactivated. The Member will be responsible for any theft charges or usage fees of any bike rented with a lost or stolen key that has not been reported to customer service. A replacement charge of $10 for the lost or damaged service key will be charged, and a replacement system key will be mailed to Member's mailing address of record.

Section 10 General Assumption of Risk by Member. Member agrees that riding a Capital Bikeshare bicycle involves many obvious and not-so-obvious risks, dangers, and hazards, which may result in injury or death to Member or others, as well as damage to property, and that such risks, dangers, and hazards cannot always be predicted or avoided. Member agrees that such risks, dangers, and hazards are Member's sole responsibility. Member agrees that if Member's use of any Service causes injury or damage to another person or property, then Member may be liable for all resulting injuries, damages, and related costs. By choosing to ride a Capital Bikeshare bicycle, Member assumes all responsibility for all related risks, dangers, and hazards, and Member agrees that Alta is not responsible for any injury, damage, or cost caused by Member with respect to any person or property, including the Capital Bikeshare bicycle itself. Member is solely and fully responsible for the safe operation of the Capital Bikeshare bicycle at all times. Member may need to take additional safety measures or precautions not specifically addressed in this Agreement.

Section 11 Confidentiality of Personal and Financial Data and Usage Information. . All personally identifiable information that is held by Alta and pertains to Members, including all names, addresses, phone numbers, email addresses, and credit card numbers, will be kept confidential by Alta; provided, however, that (i) if there is any accident where a Member is unable to communicate personal information to the appropriate authorities, then Alta may, in its sole discretion, provide the Member’s name, address, phone number, and other important information to such authorities, (ii) if Alta receives any subpoena from any court or other authority, then Alta will provide all requested information in accordance with applicable law, which may include Member names, rental dates, rental locations, and rental durations (including starting rental times and ending rental times), and (iii) Alta may disclose aggregate and other data about Members to its clients including rental dates, rental locations, rental durations (including starting rental times and ending rental times), and latitude and longitude data for Member addresses (which would not allow any individual's address to be separately identified) and (iv) Alta may disclose any or all email addresses of any or all Members to solely to any state or local government or governmental agency that participates in or is otherwise involved in the Capital Bikeshare program, upon any of their request.

Section 12 Prohibited Acts.

a. Member must not ride a Capital Bikeshare bicycle while carrying any briefcase, backpack, bag, or other item else, if it impedes Member's ability to operate a Capital Bikeshare bicycle safely.

b. Member must not use any cellular telephone, text messaging device, portable music player, or other device that may distract Member from safely operating a Capital Bikeshare bicycle; provided, however, that Member may use a cellular telephone only while employing an activated hands-free device that does not hinder Member 's ability to safely ride a Capital Bikeshare bicycle.

c. Member must not operate a Capital Bikeshare bicycle while under the influence of any alcohol, drugs, or other substance that may impair Member's ability to safely operate a Capital Bikeshare bicycle.

d. Member must not carry a second person on a Capital Bikeshare bicycle.

e. Member must not dock or lock any bicycle in any Station other than Capital Bikeshare bicycles.

f. Member must not use any locking mechanism, other than the locking mechanism provided by Alta at the Bike Dock, to lock a Capital Bikeshare bicycle to a Bike Dock.

g. Member must not violate any applicable federal, state, or local law, including those for bicycle riders.

h. Member must not dismantle or modify a Capital Bikeshare bicycle in any way. This rule does not apply to the use of the seat height adjustment feature on Capital Bikeshare bicycles.

i. Member must not exceed the maximum weight limit for the Capital Bikeshare bicycle (260 pounds) or the cargo carrier (17 pounds).

j. Member must not operate a Capital Bikeshare bicycle in extreme weather conditions, including snow, hail, and electrical storms, which make it more dangerous to operate a Capital Bikeshare bicycle. Member is advised to adjust Member's riding behavior and braking distance to suit the weather conditions.

k. Member must not allow others to use a Capital Bikeshare bicycle that Member has removed from a Bike Dock. Member understands that when Member removes from a Capital Bikeshare bicycle from a Bike Dock, it is to be used only by Member. Member must not transfer Member's system key, 7-digit code on the system key, 5-digit code at the Pay Station or any other Account information to any other person.

Section 13 Additional Membe r Obligations.

a. Member agrees that Member is a competent bicycle operator, is sufficiently fit to safely operate a Capital Bikeshare bicycle, and has received medical clearances for such physical activity. Like any physical activity, riding a Capital Bikeshare bicycle may cause minor or major injuries or discomfort and may worsen or complicate underlying medical conditions or diseases. By choosing to ride a Capital Bikeshare bicycle, Member assumes all responsibility for all such injuries or other medical conditions.

b. Member agrees that bicycles are machines that may malfunction, even if the bicycle is properly maintained, and that such malfunction may cause injury. Member agrees that before using a Capital Bikeshare bicycle, Member must conduct a safety inspection of the Capital Bikeshare bicycle, which includes inspecting the following: (i) proper tire pressure; (ii) trueness of the wheels; (iii) safe operation of all brakes and lights; (iv) proper attachment of the seat, pedals, and basket; (v) good condition of the frame; and (vi) any sign of damage, unusual or excessive wear, or other mechanical problem or maintenance need. Member agrees not to ride the Capital Bikeshare bicycle if Member notices any mechanical or other problem or safety issue, and Member agrees to promptly notify Alta of all problems and issues and to use a different Capital Bikeshare bicycle. Member agrees to press the "Faulty Bike" button within 1 minute of docking a Capital Bikeshare bicycle that Member notices has any mechanical or other problem or safety issue.

c. Member agrees that Alta does not provide or maintain places where to ride Capital Bikeshare bicycles, and that Alta does not guarantee that there will always be a safe place to ride a Capital Bikeshare bicycle. Roads, bicycle lanes, and bicycle routes may become dangerous due to weather, traffic, or other hazards. Member must not use a Capital Bikeshare bicycle for racing, riding off road, or any other use, besides safe operation on public or private roads or property and designated bicycle routes.

d. Member agrees that Alta is not a common carrier. Alternative means of public and private transportation are available to the general public and to Member individually, including public buses and light rail service, taxis, and pedestrian paths. Alta provides Capital Bikeshare bicycles only as a convenience, and such rental availability is intended by Alta to be used only by those persons who are able and qualified to operate a Capital Bikeshare bicycle on their own and who have agreed to all terms and conditions of this Agreement.

e. Member must return the Capital Bikeshare bicycle to a Station and must insert the Capital Bikeshare bicycle into a Bike Dock, within 24 hours from the time the Capital Bikeshare bicycle was originally removed from a Bike Dock. Member agrees that if the Capital Bikeshare bicycle is not returned to a Station and inserted into a Bike Dock within 24 hours, then the Capital Bikeshare bicycle is deemed missing or stolen, and Member does hereby authorize Alta to charge Member's credit card a $1,000 fee.

f. Member agrees that Alta may require Member to return a Capital Bikeshare bicycle at any time.

g. Member agrees that access to the Service is denied to any person less than 16 years of age, whether or not accompanied by a parent or guardian. Minors who are at least 16 years of age may use the Service, but only if the Service is subscribed for by or under the responsibility of the minor's parent or guardian; and, the parent or guardian is fully liable for all injuries, damages, and costs caused by the minor's use of the Service.

h. Member must report all accidents and injuries involving a Capital Bikeshare bicycle to the local authorities and to Capital Bikeshare's Customer Service at 1-877-430-BIKE (2453) as soon as possible, but in no event later than 24 hours after the occurrence of the accident or injury.

i. Member agrees if Member is unable to report identifying information due to a medical emergency, Alta may, at its discretion, provide personal and contact information to the authorities upon their request.

Section 14 Additional Fees. If the Capital Bikeshare bicycle is not returned to a Bike Dock within the Permitted Period of Continuous Use, then Member will be charged a fee of $1,000. Such fees may be charged as soon as 24 hours after the Capital Bikeshare bicycle is not returned or is returned in a damaged state. Alta will attempt to contact the Member via telephone and email before charging the Member's credit card, by using the contact information provided by the Member when subscribing to the Service. If the member is unable to return a Capital Bikeshare bicycle to a Bike Dock, and requests the bike be picked up by Alta staff, Alta, at its sole discretion, may choose to charge the member a $30 pick-up fee. All usage fees accrued during the time the bicycle is not docked will be the responsibility of the member. If the bicycle is abandoned by the member without contacting the customer service center, the member will be responsible for all usage fees until the bike is recovered and redocked, plus a $30 service charge to recover the bike. Rider agrees to pay for any damage to a Capital Bikeshare bicycle attributable to the Member, including replacement parts and repair charges, even if the damage was caused by a third party. All repairs needed as a result of any destruction or damage, will be charged to Rider at the normal, customary labor rates. Such fees may be charged as soon as 24 hours after the Capital Bikeshare bicycle is returned in a damaged state. Alta will attempt to contact the Member via telephone and email before charging the Member's credit card, by using the contact information provided by the Member when subscribing to the Service.

Section 15 Helmets. Wearing a Snell, CPSC, ANSI, or ASTM approved helmet, properly sized, fitted, and fastened, while cycling may protect against an injury, or may lessen the severity of an injury, caused by an impact to the head; however, bicycle helmets are not 100% effective, do not protect against all head injuries, and do not protect against other injuries. Although some state and local laws do not require bicycle riders to wear helmets, Alta recommends that all riders wear a Snell, CPSC, ANSI, or ASTM approved helmet that has been properly sized, fitted, and fastened, according to the manufacturer's instructions. Alta does not represent or warrant the quality or safety characteristics of any helmet, and Member agrees that Alta must not be held liable for any injury suffered by Member while using the Service, whether or not Member is wearing a helmet at the time of injury.

Section 16 Credit Card Matters. You must input a valid credit card number and expiration date before You will be allowed to use the Service, and You do hereby represent and warrant that You are authorized to use the credit card (Alta accepts only Visa or MasterCard). You do hereby authorize Alta to charge Your credit card for all expenses incurred on Your Account, including all additional fees and repair charges. If you dispute any charge on Your Account, then you must contact Alta within 10 days of Your receipt of Your statement containing the disputed charge. Members have an on-going duty to update all changes relating to their credit card. A $101 charge will be put on the Casual Member's credit card when a Casual Member signs up for the service at the Pay Station in order to validate the card Alta uses www.authorize.net ("Processor") as Our transaction payment processor. The transmission of data to Processor and the approval of a credit card should take less than 10 seconds; however, a credit card might not allow for an overcharge/overdraft, which means that a Member's transaction request could be denied. All denials of a transaction by a Member's bank, all holds, and all other similar issues are the Member's sole responsibility and should be dealt with between the Member and his or her bank. Alta takes reasonable steps to ensure that all data transmitted by Alta is done safely and privately; however, despite those steps, Alta cannot guarantee the complete security of all credit card and other data transmitted by Alta or Processor. Please review the DISCLAIMERS and LIMITED LIABILITY sections set forth below, which are applicable to Member's use of the Service, including the transmission of credit card and other data.

Section 17 Termination. Member may terminate Member 's use of the Service at any time, and Member may cancel Member's Membership at any time; provided, however, that (i) no refund will be provided by Alta, (ii) the term of this Agreement continues in accordance with Section 2 of this Agreement, (iii) the hold may remain on Member's credit card account for up to 10 days, even if Member terminates Member 's use of the Service, and (iv) Member may still be charged any applicable additional fees in accordance with Section 13 of this Agreement.

Section 18 Choice of Law; Dispute Resolution. This Agreement is governed by, and must be construed and enforced in accordance with, the laws of the District of Columbia, excluding principles of conflicts of laws. For every dispute regarding this Agreement: (i) the prevailing party is entitled to its costs, expenses, and reasonable attorney fees (whether incurred at trial, on appeal, or otherwise) incurred in resolving or settling the dispute, in addition to all other damages or awards to which the party may be entitled; (ii) each party consents to the jurisdiction of the courts of District of Columbia and agrees that those courts have personal jurisdiction over each party; (iii) venue must be in District of Columbia; and (iv) the parties must submit the dispute to mandatory mediation held in District of Columbia. Every mediation must be completed within 4 months of the date when the initial notice demanding mediation was provided by any party. If, for any reason, the dispute is not resolved through mediation within the 4-month period, then the parties may continue seeking to resolve the dispute by use of any process, including litigation by trial.

Section 19 Waiver. No waiver of any breach of any provision of this Agreement is a waiver of any other breach or of any other provision of this Agreement. The terms of this Agreement may be waived or amended only in writing and only by the party that is entitled to the benefits of the term being waived or amended

Section 20 Cumulative Remedies. All rights and remedies granted under or referred to in this Agreement are cumulative and nonexclusive, and resort to one does not preclude resort to another or to any other right or remedy provided by law.

Section 21 Final Agreement. This Agreement contains the complete, final, and exclusive integrated agreement between the parties with respect to its subject matter. This Agreement supersedes all other prior agreements, written or oral, relating to such subject matter. At any time and from time to time, and without Member's consent, Alta may unilaterally amend, modify, or change this Agreement, in its sole discretion and without any notice or cause. By continuing to use any Service after any amendment, modification, or change, Member has agreed to be bound by all such amendments, modifications, and changes. Member must carefully review this Agreement on a regular basis to maintain awareness of all amendments, modifications, and changes.

Section 22 Representations. Each party ("Promising Party") represents and warrants to the other party that: (i) the Promising Party has the legal power and authority to enter into this Agreement and to undertake and perform all of its duties and obligations hereunder; (ii) there is no contract or other legal obligation that prevents the Promising Party from entering into this Agreement or from undertaking or performing all of its duties

Section 23 Contract Interpretation. The headings in this Agreement do not affect the interpretation of this Agreement. "Or" is not be exclusive in its meaning. "Including" means "including, but not limited to." "Herein," "hereunder," and other similar terms refer to this Agreement as a whole and are not limited to the specific section on paragraph where they appear. Plural terms refer to all members of the relevant class, and singular terms refer to one or more members of the relevant class. All pronouns include the masculine, feminine, and neuter pronoun forms. All schedules and exhibits referred to herein are hereby incorporated by reference.

Section 24 Notices. You may contact Alta by writing, calling, or emailing Alta at the street address, telephone number, and email address listed below:

Alta Bicycle Share, Inc.

711 SE Grand Ave.

Portland, OR 97214

Customer Service: 877-430-BIKE (2453)

customerservice@capitalbikeshare.com

Section 25 Releases. "Claims" means, collectively, any and all claims, injuries, demands, liabilities, disputes, causes of action (including statutory, contract, negligence, or other tort theories), proceedings, obligations, debts, liens, fines, charges, penalties, contracts, promises, costs, expenses (including attorneys' fees, whether incurred at trial, on appeal, or otherwise), damages (including consequential, compensatory, or punitive damages), or losses (whether known, unknown, asserted, unasserted, fixed, conditional, or contingent) that arise from or relate to any Service, Capital Bikeshare bicycle, Station, Bike Dock, or related information, including Member's use of any of the foregoing. In exchange for being allowed to use any Service, Capital Bikeshare bicycle, Station, Bike Dock, or related information, Member (acting for Member and for all of Member 's agents, affiliates, representatives, successors, heirs, and assigns) does hereby (i) fully and forever release and discharge Alta and all of its owners, officers, directors, affiliates, employees, agents, representatives, successors, and assigns (collectively, "Alta and its Related Parties") from all Claims that Member has or may have against Alta and its Related Parties, except for Claims caused by Alta's gross negligence or willful misconduct, and (ii) Member agrees to indemnify and hold harmless Alta and its Related Parties from and against all Claims, except for Claims caused by Alta's gross negligence or willful misconduct. Such releases are intended to be general and complete releases of all Claims. Alta and its Related Parties may plead such releases as a complete and sufficient defense to any Claim, as intended 3rd beneficiaries of such releases.

Section 26 DISCLAIMERS. YOU DO HEREBY ACKNOWLEDGE AND AGREE THAT YOUR USE OF ANY SERVICE, BICYCLE, STATION, BIKE DOCK, OR RELATED INFORMATION IS AT YOUR SOLE RISK. TO THE FULLEST EXTENT PERMITTED BY LAW, ALTA AND ITS RELATED PARTIES DISCLAIM ALL EXPRESS AND IMPLIED WARRANTIES, INCLUDING WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE, COMPATIBILITY, SECURITY, ACCURACY, NONINFRINGEMENT, AND USEFULNESS, WITH RESPECT TO ANY SERVICE, BICYCLE, STATION, BIKE DOCK, OR RELATED INFORMATION, WHICH ARE ALL PROVIDED "AS IS" AND "AS AVAILABLE" (AND YOU RELY ON THEM SOLELY AT YOUR OWN RISK). WE DO NOT REPRESENT OR WARRANT THAT ANY SERVICE, BICYCLE, STATION, BIKE DOCK, OR RELATED INFORMATION WILL BE IN GOOD REPAIR OR ERROR-FREE, AND DELAYS, OMISSIONS, INTERRUPTIONS, OR INACCURACIES COULD EXIST IN ANY SERVICE, BICYCLE, STATION, BIKE DOCK, OR INFORMATION. YOU ASSUME FULL RESPONSIBILITY AND RISK OF LOSS FOR USING ANY SERVICE, BICYCLE, STATION, BIKE DOCK, OR RELATED INFORMATION, AND WE ARE NOT LIABLE FOR ANY CLAIM ATTRIBUTABLE TO ANY OF THE FOREGOING.

Section 27 LIMITED LIABILITY. YOU DO HEREBY ACKNOWLEDGE AND AGREE THAT ALTA AND ITS RELATED PARTIES ARE NOT RESPONSIBLE OR LIABLE FOR ANY CLAIM, INCLUDING THOSE THAT ARISE OUT OF OR RELATE TO (A) ANY RISK, DANGER, OR HAZARD DESCRIBED IN THIS AGREEMENT, (B) YOUR USE OF, OR INABILITY TO USE, ANY SERVICE, BICYCLE, STATION, BIKE DOCK, OR RELATED INFORMATION, (C) YOUR BREACH OF THIS AGREEMENT OR YOUR VIOLATION OF ANY LAW, (D) ANY NEGLIGENCE, MISCONDUCT, OR OTHER ACTION OR INACTION BY YOU, (E) YOUR FAILURE TO WEAR A BICYCLE HELMET WHILE USING A CAPITAL BIKESHARE BICYCLE, OR (F) ANY NEGLIGENCE, MISCONDUCT, OR OTHER ACTION OR INACTION OF ANY THIRD PARTY. YOU DO HEREBY WAIVE ALL CLAIMS WITH RESPECT TO ANY OF THE FOREGOING, INCLUDING THOSE BASED IN CONTRACT, TORT (INCLUDING NEGLIGENCE), STATUTORY, OR OTHER GROUNDS, EVEN IF WE HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH CLAIMS. OUR TOTAL LIABILITY FOR ALL CLAIMS, INCLUDING THOSE BASED IN CONTRACT, TORT (INCLUDING NEGLIGENCE), STATUTORY, OR OTHER GROUNDS, IS LIMITED TO THE SUM OF $100. SOME JURISDICTIONS DO NOT ALLOW FOR LIMITED LIABILITY OR EXCLUSION OF IMPLIED WARRANTIES; AND, IF ANY OF THOSE LAWS APPLY TO YOU, THEN SOME OR ALL OF THE ABOVE DISCLAIMERS, EXCLUSIONS, OR LIMITATIONS MIGHT NOT APPLY TO YOU, AND YOU MIGHT HAVE ADDITIONAL RIGHTS.

Click here to view the Rental Agreement in a separate window

Check ONE field below:

* I certify that I am the Member, I am 18 years old or over, and I have read and agree to the conditions set forth in User Agreement.

OR

* I certify that I am the Parent and/or Legal Guardian of the Member, who is at least 16 years old, and I am 18 years old or over. I have read, and I agree to, the conditions set forth in the User Agreement on behalf of the Member.

Safety * I have read the contents of the Safety page on this Website, and agree to abide by the safety guidelines described on the Safety page, and in the User Agreement.

*Mandatory fields